<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" 
	xmlns:MadCap="http://www.madcapsoftware.com/Schemas/MadCap.xsd" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- Include a library of unit conversions. Held separately so it can be updated without introducing risk to the main conversion -->
	<xsl:include href="convertLibrary.xsl"/>

<!-- Set output style. HTML with no indentations. Normally no. -->
	<xsl:output method="html" indent="yes" omit-xml-declaration="yes"/>

<!-- Set global variables. This reads the path variable sent from Flare that creates an absolute path. --> 
	<xsl:variable name="rawPath"><xsl:value-of select="unparsed-text('..\path.txt','UTF-8')"/></xsl:variable>
	<xsl:variable name="stringLength"><xsl:value-of select="string-length($rawPath)"/></xsl:variable>
	<xsl:variable name="projectPath"><xsl:value-of select="substring($rawPath,1,$stringLength - 3)"/></xsl:variable>
	<xsl:variable name="scripts"><xsl:value-of select="$projectPath"/>Content\javascript.xml</xsl:variable>	

<!-- Begin traversing the list of files in the output folder -->
	<xsl:template match="file_list">
		<xsl:for-each select="*">
			<xsl:variable name="filename" select="."/>
			<xsl:variable name="content" select="document($filename)"/>
<!-- Generate a new output file to replace the Flare generated file. Uses the same file name. Transparent to the end user -->
			<xsl:result-document href="{$filename}" method="html">
				<xsl:apply-templates select="document($filename)">
					<xsl:with-param name="content" select="$content"/>
				</xsl:apply-templates>
			</xsl:result-document>

		</xsl:for-each>

	</xsl:template>

<!-- Recreate each node as it appears in the generated document -->
	<xsl:template match="*">
		<xsl:param name="content"/>
		<xsl:variable name="name" select="name(.)"/>
		<xsl:element name="{$name}">
			<xsl:for-each select="@*">
				<xsl:copy-of select="."/>
			</xsl:for-each>
<!-- Recursive apply-templates allows you to find the conversion spans --> 
			<xsl:apply-templates/>
			</xsl:element>
	</xsl:template>

<!-- Formatting the output. We choose to format the output as original, which was standard with metric in parens -->
<!-- You can have multiple return functions -->
<!-- Provides a high level of consistency -->
	<xsl:template name="return">
		<xsl:param name="original"/>
		<xsl:param name="converted"/>
		<xsl:value-of select="$original"/> (<xsl:value-of select="$converted"/>)
	</xsl:template>

</xsl:stylesheet>
