<xsl:stylesheet version="2.0" 
	xmlns:MadCap="http://www.madcapsoftware.com/Schemas/MadCap.xsd" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- Each template match looks for a span with a class attribute that describes the unit conversion -->
	<xsl:template match="span[@class='ft-m']">
<!-- Parses out the original unit of measure -->
		<xsl:variable name="units"><xsl:number value="substring-before(.,'ft')"/></xsl:variable>
<!-- Math -->
		<xsl:variable name="converted" select="$units div 3.2808"/>

<!-- Send the output to another template to format it. This is an optional step. You may choose to format it here instead. -->
		<xsl:call-template name="return">
			<xsl:with-param name="original" select="."/>
			<xsl:with-param name="converted"><xsl:value-of select="format-number($converted,'###,##0.0#')"/>m</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="span[@class='in-m']">
		<xsl:variable name="units"><xsl:number value="substring-before(.,'in')"/></xsl:variable>
		<xsl:variable name="converted" select="$units div 39.370"/>
		<xsl:call-template name="return">
			<xsl:with-param name="original" select="."/>
			<xsl:with-param name="converted"><xsl:value-of select="format-number($converted,'###,##0.0#')"/>m</xsl:with-param>
		</xsl:call-template>
	</xsl:template>


	<xsl:template match="span[@class='in-cm']">
		<xsl:variable name="units"><xsl:number value="substring-before(.,'in')"/></xsl:variable>
		<xsl:variable name="converted" select="$units * 2.54"/>
		<xsl:call-template name="return">
			<xsl:with-param name="original" select="."/>
			<xsl:with-param name="converted"><xsl:value-of select="format-number($converted,'###,##0.0#')"/>cm</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="span[@class='cm-in']">
		<xsl:variable name="units"><xsl:number value="substring-before(.,'cm')"/></xsl:variable>
		<xsl:variable name="converted" select="$units * 0.39370"/>
		<xsl:call-template name="return">
			<xsl:with-param name="original" select="."/>
			<xsl:with-param name="converted"><xsl:value-of select="format-number($converted,'###,##0.0#')"/>in</xsl:with-param>
		</xsl:call-template>
	</xsl:template>


	<xsl:template match="span[@class='gy-rd']">
		<xsl:variable name="units"><xsl:number value="substring-before(.,'gy')"/></xsl:variable>
		<xsl:variable name="converted" select="$units * 100"/>

		<xsl:call-template name="return">
			<xsl:with-param name="original" select="."/>
			<xsl:with-param name="converted"><xsl:value-of select="format-number($converted,'###,##0')"/> rads</xsl:with-param>
		</xsl:call-template>
	</xsl:template>





</xsl:stylesheet>