<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" 
	xmlns:MadCap="http://www.madcapsoftware.com/Schemas/MadCap.xsd" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- Set output style. HTML with no indentations. Normally no. -->
	<xsl:output method="html" indent="yes" omit-xml-declaration="yes"/>


<!-- Set global variables. This reads the path variable sent from Flare that creates an absolute path. --> 
	<xsl:variable name="rawPath"><xsl:value-of select="unparsed-text('..\path.txt','UTF-8')"/></xsl:variable>
	<xsl:variable name="stringLength"><xsl:value-of select="string-length($rawPath)"/></xsl:variable>
	<xsl:variable name="projectPath"><xsl:value-of select="substring($rawPath,1,$stringLength - 3)"/></xsl:variable>

<!-- Reads the keyword list text file into memory as a global variable. -->
	<xsl:variable name="keywordList"><xsl:value-of select="$projectPath"/>Content\keywordList.xml</xsl:variable>	


<!-- Begin traversing the list of files in the output folder -->
	<xsl:template match="file_list">

		<xsl:for-each select="*">
			<xsl:variable name="filename" select="."/>
			<xsl:variable name="content" select="document($filename)"/>
			<xsl:result-document href="{$filename}" method="html">
				<xsl:apply-templates select="document($filename)">
					<xsl:with-param name="content" select="$content"/>
				</xsl:apply-templates>
			</xsl:result-document>

		</xsl:for-each>

	</xsl:template>

<!-- Recreate each node as it appears in the generated document -->
	<xsl:template match="*">
		<xsl:param name="content"/>
		<xsl:param name="bodyContent"/>
		<xsl:variable name="name" select="name(.)"/>
		<xsl:element name="{$name}">
			<xsl:for-each select="@*">
				<xsl:copy-of select="."/>
			</xsl:for-each>
			<xsl:apply-templates>
				<xsl:with-param name="content" select="$content"/>
			</xsl:apply-templates>
			</xsl:element>
	</xsl:template>

<!-- When you find the head node, do these things -->
	<xsl:template match="head">
		<xsl:param name="content"/>

		<xsl:variable name="name" select="name(.)"/>
		<xsl:element name="{$name}">

<!-- Back up one level in the XML-tree and place the contents of the body node in a variable -->
				<xsl:variable name="bodyContent" select="../body"/>
<!-- Create an element in the head node called meta with a name attribute with the value description. -->
<!-- This is your metadata node -->
					<xsl:element name="meta">
						<xsl:attribute name="name">description</xsl:attribute>
						<xsl:attribute name="content">
<!-- If a metadata node with the name description already exists, copy the content of that node here -->
							<xsl:if test="meta[@name = 'description']/@content"><xsl:value-of select="meta[@name = 'description']/@content"/>,</xsl:if>
<!-- Traverse the keyword list and do these things -->
<!-- Convert the keyword to all lower case to eliminate case-based false negatives -->
<!-- Convert the conent of the body node to lower case -->
<!-- Test if the body node CONTAINS the keyword -->
<!-- If yes, place the original keyword in the metadata node. -->
<!-- If no, go to the next keyword in the list and repeat -->
							<xsl:for-each select="document($keywordList)/keywordList/list/keyword[contains(translate($bodyContent,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),translate(.,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'))]">
								<xsl:value-of select="."/><xsl:if test="position() != last()">,</xsl:if>
							</xsl:for-each>
							<xsl:for-each select="document($keywordList)/keywordList/all/text()">,<xsl:value-of select="."/></xsl:for-each>
							</xsl:attribute>
					</xsl:element>
					<xsl:apply-templates select="*[not(@name='description')]"/>

		</xsl:element>

	</xsl:template>


</xsl:stylesheet>
